# AnimalAI
![steampunkFOURcrop](https://github.com/Kinds-of-Intelligence-CFI/animal-ai/assets/65875290/df798f4a-cb2c-416f-a150-093b9382a621)
Animal-AI (3) Python Project

This repository is responsible for managing and updating primarily the PyPI package (https://pypi.org/project/animalai/) for Animal-AI package dependencies. 

The main project repository is located [here](https://github.com/Kinds-of-Intelligence-CFI/animal-ai)

The Animal-AI (3) Unity project repository is located [here](https://github.com/Kinds-of-Intelligence-CFI/animal-ai-unity-project)

![PyPI Downloads](https://img.shields.io/pypi/dm/animalai) | ![PyPI Downloads](https://img.shields.io/pypi/dw/animalai) | ![PyPI Downloads](https://img.shields.io/pypi/dd/animalai)



- **Website:** [https://www.animalai.org](https://animalai.org/)
- **Documentation:** [https://animalai.org/doc](https://github.com/Kinds-of-Intelligence-CFI/animal-ai/tree/main/docs)
- **Unity Source code:** [https://github.com/Kinds-of-Intelligence-CFI/animal-ai-unity-project](https://github.com/Kinds-of-Intelligence-CFI/animal-ai-unity-project)
-  **Python Source code:** [https://github.com/Kinds-of-Intelligence-CFI/animal-ai-package/tree/main/animalai](https://github.com/Kinds-of-Intelligence-CFI/animal-ai-package/tree/main/animalai)
- **Bug reports:** [https://github.com/Kinds-of-Intelligence-CFI/animal-ai/issues](https://github.com/Kinds-of-Intelligence-CFI/animal-ai/issues)

For more information about the ways you can contribute to AnimalAI, visit our website. If you’re unsure where to start or how your skills fit in, reach out! You can ask on GitHub, by opening a new issue or leaving a comment on a relevant issue that is already open.

If you are new to contributing to open source, [this](https://opensource.guide/how-to-contribute/) guide helps explain why, what, and how to successfully get involved.

## Version History
- v3.0.5
  - Removed redundant packages in setup.py.
  - Added monthly download stats.
- v3.0.4
  - Added current and past contributers.
  - Added project description and metadata.
- v3.0.3
  - Asserted python version to be 3.6.1 or higher, but less than 3.10.0 (exclusive).
  - Added package description to setup.py and package metadata.
- v3.0.2
  - Fixed major pacakge dependency issues, related to mlagents 0.30.0, protopuf, and shimy.
  - Updated project setup.py to accomodate the latest version of Animal-AI package dependencies.
    - Users can now use # pip install animalai # to install from PyPI directly (previously had to be done via locally). 
